/**
 * Minify URLs.
 *
 * @param {Options | null | undefined} [options]
 *   Configuration (optional).
 * @returns
 *   Transform.
 */
export default function rehypeMinifyUrl(options?: Options | null | undefined): (tree: Root, file: VFile) => undefined;
export type Root = import('hast').Root;
export type Properties = import('hast').Properties;
export type RelateUrl = import('relateurl');
export type RelateOptions = import('relateurl').Options;
export type VFile = import('vfile').VFile;
/**
 * Extra fields.
 */
export type ExtraFields = {
    /**
     * Absolute URL to where the document will be hosted (optional); can also be
     * set with an `origin` and `pathname` in `file.data.meta` (as supported by
     * [`rehype-meta`](https://github.com/rehypejs/rehype-meta)).
     */
    from?: string | null | undefined;
};
export type Objects = Extract<PropertyValue, Array<any>>;
export type Primitives = Exclude<PropertyValue, Array<any>>;
/**
 * Configuration.
 *
 * All options except for `from` are passed through to
 * [`relateurl`](https://github.com/stevenvachon/relateurl).
 */
export type Options = RelateOptions & ExtraFields;
export type PropertyValue = Properties[keyof Properties];
